@@ -679,7 +679,7 @@ static int return_file(
   close(fds);
 
   if (remove_file == TRUE && rc == 0)
-    unlink(filename);
+    job_unlink_file(pjob, filename);
 
   return(rc);
   }  /* END return_file() */
@@ -1422,9 +1422,10 @@ const char *TJobAttr[] =
   "restartname",
   "faulttol",
   "comp_time",
-  "reported",
+  "reported",      /* 60 */
   "job_type",
   "inter_cmd",
+  "proxy_user",
 #ifdef USEJOBCREATE
   "pagg_id",
 #endif /* USEJOBCREATE */
